==> humhub-1.3.18.tar.gz: humhub-1.3.18/protected/humhub/modules/ldap/messages/pl/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => 'TLS/SSL jest bardzo preferowany na produkcji w celu zapobiegania wysyłania haseł otwartym tekstem.',
  'Base DN' => 'Bazowy DN',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => 'Ustala filtr do zastosowania, gdy dojdzie do próby logowania. %s zastępuje nazwę użytkownika w trakcie logowania. Przykład: "(sAMAccountName=%s)" or "(uid=%s)"',
  'E-Mail Address Attribute' => 'Atrybut Adres E-Mail',
  'Enable LDAP Support' => 'Włącz wsparcie LDAP',
  'Encryption' => 'Szyfrowanie',
  'Fetch/Update Users Automatically' => 'Automatyczne Pobierz/Aktualizuj Użytkowników',
  'Hostname' => 'Nazwa Hosta',
  'ID Attribute' => 'Atrybut ID',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quotmail&quot;' => 'Atrybut LDAP dla adresów E-mail. Domyślny:  &amp;quotmail"',
  'LDAP Attribute for Username. Example: &quotuid&quot; or &quot;sAMAccountName&quot;' => 'Atrybut LDAP dla Nazwy Użytkownika. Przykład: &amp;quotuid" lub "sAMAccountName"',
  'Limit access to users meeting this criteria. Example: &quot(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => 'Ogranicz dostęp do użytkowników spełniających te kryteria. Przykład: &amp;quot(objectClass=posixAccount)" or "(&amp;(objectClass=osoba)(memberOf=CN=Pracownicy,CN=Users,DC=mojaDomena,DC=com))"',
  'Login Filter' => 'Filtr Loginów',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => 'Niezmienny atrybut LDAP do jednoznacznego identyfikowania użytkowników w katalogu. Jeżeli puste użytkownik ozstanie zidentyfikowany automatycznie prze adres e-mail lub nazwę użytkownika. Przykład: objectguid (ActiveDirectory) lub uidNumber (OpenLDAP)',
  'Password' => 'Hasło',
  'Port' => 'Port',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Wybiera',
  'Status: Error! (Message: {message})' => 'Stan: Błąd!(Wiadomość: {message})',
  'Status: OK! ({userCount} Users)' => 'Status: OK!({userCount} Użytkowników)',
  'Status: Warning! (No users found using the ldap user filter!)' => 'Stan: Ostrzeżenie! (Nie znaleziono użytkowników używając tego filtra!)',
  'The default base DN used for searching for accounts.' => 'Domyślna baza DN używana do wyszukiwania kont.',
  'The default credentials password (used only with username above).' => 'Domyślne hasło (użyte tylko dla powyższego użytkownika).',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => 'Domyślne poświadczenie użytkownika. Niektóre serwery wymagają aby to było w formie DN. To musi być podane w formie DN jeżeli serwer LDAP wymaga DN do przypisania i przypisanie powinno być możliwe z prostymi nazwami użytkownika.',
  'User Filer' => 'Filtr użytkowników',
  'Username' => 'Nazwa Użytkownika',
  'Username Attribute' => 'Atrybut Nazwy Użytkownika',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/ldap/messages/pl/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => 'TLS/SSL jest bardzo preferowany na produkcji w celu zapobiegania wysyłania haseł otwartym tekstem.',
  'Base DN' => 'Bazowy DN',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => 'Ustala filtr do zastosowania, gdy dojdzie do próby logowania. %s zastępuje nazwę użytkownika w trakcie logowania. Przykład: "(sAMAccountName=%s)" or "(uid=%s)"',
  'E-Mail Address Attribute' => 'Atrybut Adres E-Mail',
  'Enable LDAP Support' => 'Włącz wsparcie LDAP',
  'Encryption' => 'Szyfrowanie',
  'Fetch/Update Users Automatically' => 'Automatyczne Pobierz/Aktualizuj Użytkowników',
  'Hostname' => 'Nazwa Hosta',
  'ID Attribute' => 'Atrybut ID',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quot;mail&quot;' => 'Atrybut LADP dla adresu E-Mail. Domyślny "mail"',
  'LDAP Attribute for Username. Example: &quot;uid&quot; or &quot;sAMAccountName&quot;' => 'Atrybut LADP dla Użytkownika. Przykład: "uid" lub "sAMAccountName"',
  'Limit access to users meeting this criteria. Example: &quot;(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => 'Ogranicz dostęp do użytkowników spełniających te kryteria. Przykład: "(objectClass=posixAccount)" lub "(&amp;(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))"',
  'Login Filter' => 'Filtr Loginów',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => 'Niezmienny atrybut LDAP do jednoznacznego identyfikowania użytkowników w katalogu. Jeżeli puste użytkownik ozstanie zidentyfikowany automatycznie prze adres e-mail lub nazwę użytkownika. Przykład: objectguid (ActiveDirectory) lub uidNumber (OpenLDAP)',
  'Password' => 'Hasło',
  'Port' => 'Port',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Wybiera',
  'Status: Error! (Message: {message})' => 'Stan: Błąd!(Wiadomość: {message})',
  'Status: OK! ({userCount} Users)' => 'Status: OK!({userCount} Użytkowników)',
  'Status: Warning! (No users found using the ldap user filter!)' => 'Stan: Ostrzeżenie! (Nie znaleziono użytkowników używając tego filtra!)',
  'The default base DN used for searching for accounts.' => 'Domyślna baza DN używana do wyszukiwania kont.',
  'The default credentials password (used only with username above).' => 'Domyślne hasło (użyte tylko dla powyższego użytkownika).',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => 'Domyślne poświadczenie użytkownika. Niektóre serwery wymagają aby to było w formie DN. To musi być podane w formie DN jeżeli serwer LDAP wymaga DN do przypisania i przypisanie powinno być możliwe z prostymi nazwami użytkownika.',
  'User Filer' => 'Filtr użytkowników',
  'Username' => 'Nazwa Użytkownika',
  'Username Attribute' => 'Atrybut Nazwy Użytkownika',
);
